@@ -1,4 +1,4 @@
-//$Id: main.cc 398 2005-04-19 14:42:11Z murrayc $ -*- c++ -*-
+//$Id: main.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -24,7 +24,8 @@ int main(int argc, char *argv[])
   Gtk::Main kit(argc, argv);
 
   ExampleWindow window;
-  Gtk::Main::run(window); //Shows the window and returns when it is closed.
+  //Shows the window and returns when it is closed.
+  Gtk::Main::run(window);
 
   return 0;
 }
